@@ -1,3 +1,6 @@
+# Copyright 2021 VMware, Inc.
+# SPDX-License-Identifier: Apache License 2.0
+
 """
     want to do somthing helpful
     write down those here
@@ -190,8 +193,8 @@ def printProgressBar(iteration, total, msg, prefix='', suffix='', decimals=1,
     filledLength = int(length * iteration // total)
     bar = fill * filledLength + '-' * (length - filledLength)
     if (iteration < total):
-        print '\r%s |%s| %s%% %s' % (prefix, bar, percent, suffix),
+        print('\r%s |%s| %s%% %s' % (prefix, bar, percent, suffix),)
     else:
-        print '\r%s |%s| %s%% %s' % (prefix, bar, percent, suffix)
-        print 'completed'
-        print '\n'
+        print('\r%s |%s| %s%% %s' % (prefix, bar, percent, suffix))
+        print('completed')
+        print('\n')
