@@ -9,7 +9,8 @@ import random
 import copy
 import xlsxwriter
 import logging
-
+from avi.migrationtools.nsxt_converter.conversion_util import NsxtConvUtil
+from avi.migrationtools.avi_migration_utils import MigrationUtil
 from avi.migrationtools.nsxt_converter import nsxt_client as nsx_client_util
 import pprint
 from avi.sdk.avi_api import ApiSession
@@ -17,8 +18,9 @@ from avi.sdk.avi_api import ApiSession
 pp = pprint.PrettyPrinter(indent=4)
 vs_details = {}
 controller_details = {}
-
+conv_utils = NsxtConvUtil()
 LOG = logging.getLogger(__name__)
+common_avi_util = MigrationUtil()
 
 
 def is_segment_configured_with_subnet(vs_id, cloud_name, cloud_tenant):
@@ -107,6 +109,10 @@ def get_lb_skip_reason(vs_id):
         return vs_details.get(vs_id).get("lb_skip_reason")
     return None
 
+def get_warning_mesg(vs_id):
+    if vs_details.get(vs_id):
+        return vs_details.get(vs_id).get("warning_mesg")
+    return None
 
 def get_vs_details(vs_id):
     if vs_details.get(vs_id):
@@ -139,45 +145,52 @@ def get_certificate_data(certificate_ref, nsxt_ip, ssh_root_password):
     import paramiko
     import json
 
-    ssh = paramiko.SSHClient()
-    ssh.load_system_host_keys()
-    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
-    ssh.connect(nsxt_ip, username='root', password=ssh_root_password, allow_agent=False, look_for_keys=False)
+    try:
+        ssh = paramiko.SSHClient()
+        ssh.load_system_host_keys()
+        ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+        ssh.connect(nsxt_ip, username='root', password=ssh_root_password,
+                    allow_agent=False, look_for_keys=False, banner_timeout=60)
 
-    data = None
-    cmd = "curl --header 'Content-Type: application/json' --header 'x-nsx-username: admin' " \
-          "http://'admin':'{}'@127.0.0.1:7440/nsxapi/api/v1/trust-management/certificates".\
-        format(ssh_root_password)
-    stdin, stdout, stderr = ssh.exec_command(cmd)
+        cmd = "curl --header 'Content-Type: application/json' --header 'x-nsx-username: admin' " \
+              "http://'admin':'{}'@127.0.0.1:7440/nsxapi/api/v1/trust-management/certificates".\
+            format(ssh_root_password)
+        stdin, stdout, stderr = ssh.exec_command(cmd)
 
-    output_dict = ''
-    for line in stdout.read().splitlines():
-        output_dict += line.decode()
+        output_dict = ''
+        for line in stdout.read().splitlines():
+            output_dict += line.decode()
 
-    output_dict = json.loads(output_dict)
+        if output_dict:
+            output_dict = json.loads(output_dict)
 
-    LOG.info("output_dict for certificate_ref {}".format(certificate_ref))
-    for cert_data in output_dict['results']:
-        if 'tags' in cert_data.keys():
-            cert_id = cert_data['tags'][0]['tag'].split('/')[-1]
+            LOG.info("output_dict for certificate_ref {}".format(certificate_ref))
+            for cert_data in output_dict['results']:
+                if 'tags' in cert_data.keys() and len(cert_data['tags']) > 0:
+                    cert_id = cert_data['tags'][0]['tag'].split('/')[-1]
+                else:
+                    cert_id = cert_data['id']
+
+                if cert_id == certificate_ref:
+                    cert_command = cmd + "/" + cert_data['id'] + '/' + "?action=get_private"
+                    cert_stdin, cert_stdout, cert_stderr = ssh.exec_command(cert_command)
+                    cert_dict = ''
+                    for line in cert_stdout.read().splitlines():
+                        cert_dict += line.decode()
+
+                    cert_dict = json.loads(cert_dict)
+                    LOG.debug("cert_dict for certificate_ref {}".format(certificate_ref))
+                    if 'private_key' in cert_dict:
+                        return cert_dict['private_key'], cert_dict['pem_encoded']
         else:
-            cert_id = cert_data['id']
+            LOG.warning("No certificate data found for certificate ref {}".format(certificate_ref))
 
-        if cert_id == certificate_ref:
-            cert_command = cmd + "/" + cert_data['id'] + '/' + "?action=get_private"
-            cert_stdin, cert_stdout, cert_stderr = ssh.exec_command(cert_command)
-            cert_dict = ''
-            for line in cert_stdout.read().splitlines():
-                cert_dict += line.decode()
+        ssh.close()
+        stdin.close()
+    except Exception as e:
+        LOG.error("Error in getting certificate data for ref {}. Message: {}".format(certificate_ref, str(e)))
 
-            cert_dict = json.loads(cert_dict)
-            LOG.debug("cert_dict for certificate_ref {}".format(certificate_ref))
-            if 'private_key' in cert_dict:
-                return cert_dict['private_key'], cert_dict['pem_encoded']
-
-    ssh.close()
-    stdin.close()
-    return data
+    return None, None
 
 
 class NSXUtil():
@@ -463,6 +476,7 @@ class NSXUtil():
             cloud_name = None
             lb_details = []
             lb_tier1_lr = None
+            warning_mesg=None
             if len(interface_list):
                 interface = interface_list[0].id
                 segment_id = get_name_and_entity(interface_list[0].segment_path)[-1]
@@ -493,37 +507,51 @@ class NSXUtil():
 
             else:
                 segment_list = self.nsx_api_client.infra.Segments.list().to_dict().get('results', [])
+
+                is_tier_linked_segment_found = False
                 for seg in segment_list:
                     if seg.get("connectivity_path"):
                         gateway_name = get_name_and_entity(seg["connectivity_path"])[-1]
                         if gateway_name == tier:
+                            is_tier_linked_segment_found = True
                             tz_path = seg.get("transport_zone_path")
                             tz_id = get_name_and_entity(tz_path)[-1]
                             dhcp_present = False
                             for subnet in seg["subnets"]:
                                 if "dhcp_config" in subnet.keys() and not dhcp_present:
                                     dhcp_present = True
-                            if dhcp_present:
-                                cloud_name = self.get_cloud_type(self.cloud, tz_id, seg.get("id"), tier)
-                                if seg.get("vlan_ids"):
-                                    network = "Vlan"
-                                else:
-                                    network = "Overlay"
-                                if seg.get("subnets"):
-                                    subnets = []
-                                    for subnet in seg["subnets"]:
-                                        subnets.append({
-                                            "network_range": subnet["network"]
-                                        })
-                                    segments = {
-                                        "name": seg.get("id"),
-                                        "subnet": subnets}
-                                    lb_details.append(segments)
-                                if cloud_name == "Cloud Not Found":
-                                    continue
-                                break
+                            cloud_name = self.get_cloud_type(self.cloud, tz_id, seg.get("id"), tier)
+                            if cloud_name == "Cloud Not Found":
+                                continue
+                            is_dhcp_configured_on_avi, is_static_ip_pool_configured, is_ip_subnet_configured,\
+                            static_ip_for_se_flag = self.get_dhcp_config_details_on_avi_side(cloud_name, seg.get("id"))
 
-                if not (network and cloud_name):
+                            if not is_dhcp_configured_on_avi and (not is_static_ip_pool_configured or
+                                                                  not is_ip_subnet_configured or
+                                                                  not static_ip_for_se_flag):
+                                warning_mesg = "Warning : configuration of  %s network is incomplete ," \
+                                               "please check it once " % seg.get("display_name")
+
+                            if seg.get("vlan_ids"):
+                                network = "Vlan"
+                            else:
+                                network = "Overlay"
+                            if seg.get("subnets"):
+                                subnets = []
+                                for subnet in seg["subnets"]:
+                                    subnets.append({
+                                        "network_range": subnet["network"]
+                                    })
+                                segments = {
+                                    "name": seg.get("id"),
+                                    "subnet": subnets}
+                                lb_details.append(segments)
+                            
+                            if cloud_name == "Cloud Not Found":
+                                continue
+                            break
+
+                if not is_tier_linked_segment_found:
                     self.lb_services[lb["id"]] = {
                         "lb_name": lb["id"],
                         "lb_skip_reason": "Skipping because NSX Load Balancer has no segments "
@@ -539,7 +567,30 @@ class NSXUtil():
                 }
             if lb_details:
                 self.lb_services[lb["id"]]["Segments"] = lb_details
+            if warning_mesg:
+                self.lb_services[lb["id"]]["warning_mesg"] = warning_mesg
 
+    def get_dhcp_config_details_on_avi_side(self,cloud_name,seg_id):
+        is_dhcp_configured_on_avi = False
+        is_static_ip_pool_configured = False
+        is_ip_subnet_configured = False
+        static_ip_for_se_flag = False
+        cloud_id = [cl.get("uuid") for cl in self.cloud if cl.get("name") == cloud_name]
+        segment_list = self.session.get("network/?&cloud_ref.uuid=" + cloud_id[0]).json()["results"]
+        segment = [seg for seg in segment_list if seg.get("attrs")[0].get("value").split('segments/')[-1] == seg_id]
+        if segment :
+            is_dhcp_configured_on_avi = segment[0].get("dhcp_enabled") 
+            if segment[0].get("configured_subnets"):
+                configured_subnets = segment[0].get("configured_subnets")
+                if configured_subnets[0].get("prefix"):
+                    is_ip_subnet_configured = True
+                    if configured_subnets[0].get("static_ip_ranges"):
+                        is_static_ip_pool_configured = True
+                        if configured_subnets[0].get("static_ip_ranges")[0].get("type") in ["STATIC_IPS_FOR_VIP_AND_SE","STATIC_IPS_FOR_SE"]:
+                             static_ip_for_se_flag = True
+
+        return is_dhcp_configured_on_avi,is_static_ip_pool_configured,is_ip_subnet_configured,static_ip_for_se_flag
+           
     def get_all_virtual_service(self):
         """
         :return:list of virtual server objects
@@ -580,6 +631,7 @@ class NSXUtil():
                     vs_object['lb_name'] = lb
                     vs_object['lb_skip_reason'] = lb_details.get("lb_skip_reason")
                     vs_object['lb_tier1_lr'] = lb_details.get("lb_tier1_lr")
+                    vs_object["warning_mesg"]= lb_details.get("warning_mesg")
                     # lb_details["vs_name"] = vs["display_name"]
                     vs_details[vs["id"]] = vs_object
             if vs["enabled"]:
@@ -942,3 +994,85 @@ class NSXUtil():
                 ]
         }
         return new_network_service
+
+    def update_network_service_obj(self, network_obj, floating_ip):
+        floating_ip_list = network_obj.get("routing_service").get("floating_intf_ip")
+        is_floating_ip_found = False
+        for obj in floating_ip_list:
+            if obj.get("addr") == floating_ip:
+                is_floating_ip_found = True
+                break
+        if not is_floating_ip_found:
+            floating_ip_list.append({
+                            "addr": floating_ip,
+                            "type": "V4"
+                        })
+
+    def get_nsx_group_details(self,group_path):
+        domain_id = group_path.split('domains/')[1].split("/groups")[0]
+        ns_group_id = group_path.split('groups/')[1]
+        ns_groups_list = self.nsx_api_client.infra.domains.Groups.list(domain_id).to_dict().get("results", [])
+        ns_group = [ns_g for ns_g in ns_groups_list if ns_g['id'] == ns_group_id]
+        ns_group_name = ns_group[0]['display_name']
+        ns_ip_addr = None
+        ip_addr=self.nsx_api_client.infra.domains.groups.members.IpAddresses.list(domain_id, ns_group_id).to_dict().get("results", [])
+        if ip_addr:
+            ns_ip_addr=ip_addr
+        return ns_group_name, ns_ip_addr
+
+    def create_ns_group_policy(self, alb_vs,access_control_list, ns_ip_addr, ns_group_name, alb_config,prefix,tenant):
+        ns_policy = dict(
+            name="{}-ns".format(alb_vs['name']),
+            tenant_ref = conv_utils.get_object_ref(tenant,"tenant"),
+            rules=[]
+        )
+        rule_count = 1
+        if access_control_list.get("action") == "ALLOW":
+           action= "NETWORK_SECURITY_POLICY_ACTION_TYPE_ALLOW"
+        else:
+            action = "NETWORK_SECURITY_POLICY_ACTION_TYPE_DENY"
+        rule_dict = dict(
+            name="Rule {}".format(rule_count),
+            action=action,
+            index="1",
+            match=dict(
+                client_ip={}
+            )
+        )
+        rule_dict['enable'] = access_control_list.get("enabled")
+        ip_group_name = self.create_ip_group(ns_ip_addr, ns_group_name,alb_config, prefix,tenant)
+        rule_dict['match']["client_ip"]["group_refs"] = list()
+        rule_dict['match']["client_ip"]["group_refs"].append(conv_utils.get_object_ref
+                                                             (ip_group_name, "ipaddrgroup", tenant))
+        rule_dict['match']['client_ip']["match_criteria"] = "IS_IN"
+        ns_policy['rules'].append(rule_dict)
+        alb_config['NetworkSecurityPolicy'].append(ns_policy)
+
+        return ns_policy['name']
+
+    def create_ip_group(self, ip_addresses_list, group_name, alb_config, prefix,tenant):
+        if prefix:
+            group_name = "{}-{}-ipgroup".format(prefix, group_name)
+        is_ip_group_present = [ip_grp for ip_grp in alb_config['IpAddrGroup'] if ip_grp['name'] == group_name and
+                               ip_grp['tenant_ref'] == conv_utils.get_object_ref(tenant, 'tenant')]
+        if is_ip_group_present:
+            return group_name
+        ip_group = dict(
+            name=group_name
+        )
+        addr_list = []
+        for ip_adr in ip_addresses_list:
+            type="V6"
+            if "." in ip_adr:
+                type="V4"
+            addr_dict = dict(
+                addr=ip_adr,
+                type=type
+            )
+            addr_list.append(
+                addr_dict
+            )
+        ip_group['addrs'] = addr_list
+        ip_group['tenant_ref'] = conv_utils.get_object_ref(tenant, 'tenant')
+        alb_config['IpAddrGroup'].append(ip_group)
+        return ip_group['name']
\ No newline at end of file
