@@ -25,7 +25,11 @@ setup(
              'avi/migrationtools/config_patch.py',
              'avi/migrationtools/ansible/avi_config_to_ansible.py',
              'avi/migrationtools/f5_discovery.py',
-             'avi/migrationtools/nsxt_converter/nsxt_converter.py'],
+             'avi/migrationtools/nsxt_converter/nsxt_converter.py',
+             'avi/migrationtools/nsxt_converter/install_nsx_dependencies.py',
+             'avi/migrationtools/nsxt_converter/nsxt_traffic_cutover.py',
+             'avi/migrationtools/nsxt_converter/nsxt_rollback.py',
+             'avi/migrationtools/nsxt_converter/nsxt_cleanup.py'],
     classifiers=[
         'Operating System :: OS Independent',
         'Programming Language :: Python',
@@ -37,16 +41,11 @@ setup(
     install_requires=['pyyaml', 'requests', 'pyparsing', 'paramiko', 'avisdk',
                       'pycrypto', 'ecdsa', 'pyOpenssl', 'nose-html-reporting',
                       'nose-testconfig', 'ConfigParser', 'xlsxwriter', 'jinja2',
-                      'pandas', 'openpyxl', 'appdirs',  'pexpect',
-                      'unittest2', 'networkx', 'xmltodict',
-                      'vapi-runtime @ file://localhost/%s/avi/migrationtools/lib/vapi_runtime-2.29.0-py2.py3-none-any.whl' % (os.getcwd()),
-                      'vapi_common_client @ file://localhost/%s/avi/migrationtools/lib/vapi_common_client-2.29.0-py2.py3-none-any.whl' % (os.getcwd()),
-                      'nsx_python_sdk @ file://localhost/%s/avi/migrationtools/lib/nsx_python_sdk-4.0.0.1.0-py2.py3-none-any.whl' % (os.getcwd()),
-                      'nsx_policy_python_sdk @ file://localhost/%s/avi/migrationtools/lib/nsx_policy_python_sdk-4.0.0.1.0-py2.py3-none-any.whl' % (os.getcwd())],
+                      'pandas>=1.5.0', 'openpyxl', 'appdirs',  'pexpect',
+                      'unittest2', 'networkx', 'xmltodict'],
     package_data={'avi': ['*.cfg', '*.conf', '*.crt', '*.crl', '*.json',
                           '*.jinja', '*.key', '*.pem', '*.xml',
                           '*.yaml', '*.yml'],
-                  'avi.migrationtools.lib': ['*.whl'],
                   'avi.migrationtools.gss_convertor.parser_files': [
         "gslb_template.jinja"]
     }
